@@ -1,26 +1,25 @@
 """HVCS
 """
+import logging
 import mimetypes
 import os
 from typing import Optional
 
 import gitlab
-import ndebug
 import requests
 
 from .errors import ImproperConfigurationError
+from .helpers import LoggedFunction
 from .settings import config
 
-debug = ndebug.create(__name__)
-debug_gh = ndebug.create(__name__ + ':github')
-debug_gl = ndebug.create(__name__ + ':gitlab')
+logger = logging.getLogger(__name__)
+
 
 # Add a mime type for wheels
-mimetypes.add_type('application/octet-stream', '.whl')
+mimetypes.add_type("application/octet-stream", ".whl")
 
 
 class Base(object):
-
     @staticmethod
     def domain() -> str:
         raise NotImplementedError
@@ -35,7 +34,8 @@ class Base(object):
 
     @classmethod
     def post_release_changelog(
-            cls, owner: str, repo: str, version: str, changelog: str) -> bool:
+        cls, owner: str, repo: str, version: str, changelog: str
+    ) -> bool:
         raise NotImplementedError
 
     @classmethod
@@ -44,10 +44,27 @@ class Base(object):
         return True
 
 
+def _fix_mime_types():
+    """Fix incorrect entries in the `mimetypes` registry.
+    On Windows, the Python standard library's `mimetypes` reads in
+    mappings from file extension to MIME type from the Windows
+    registry. Other applications can and do write incorrect values
+    to this registry, which causes `mimetypes.guess_type` to return
+    incorrect values, which causes TensorBoard to fail to render on
+    the frontend.
+    This method hard-codes the correct mappings for certain MIME
+    types that are known to be either used by python-semantic-release or
+    problematic in general.
+    """
+    mimetypes.add_type("text/markdown", ".md")
+
+
 class Github(Base):
     """Github helper class
     """
-    API_URL = 'https://api.github.com'
+
+    API_URL = "https://api.github.com"
+    _fix_mime_types()
 
     @staticmethod
     def domain() -> str:
@@ -55,7 +72,7 @@ class Github(Base):
 
         :return: The Github domain
         """
-        return 'github.com'
+        return "github.com"
 
     @staticmethod
     def token() -> Optional[str]:
@@ -63,9 +80,10 @@ class Github(Base):
 
         :return: The Github token environment variable (GH_TOKEN) value
         """
-        return os.environ.get('GH_TOKEN')
+        return os.environ.get("GH_TOKEN")
 
     @staticmethod
+    @LoggedFunction(logger)
     def check_build_status(owner: str, repo: str, ref: str) -> bool:
         """Check build status
 
@@ -75,15 +93,14 @@ class Github(Base):
 
         :return: Was the build status success?
         """
-        url = '{domain}/repos/{owner}/{repo}/commits/{ref}/status'
+        url = "{domain}/repos/{owner}/{repo}/commits/{ref}/status"
         response = requests.get(
             url.format(domain=Github.API_URL, owner=owner, repo=repo, ref=ref)
         )
-        if debug_gh.enabled:
-            debug_gh('check_build_status: state={}'.format(response.json()['state']))
-        return response.json()['state'] == 'success'
+        return response.json()["state"] == "success"
 
     @classmethod
+    @LoggedFunction(logger)
     def create_release(cls, owner: str, repo: str, tag: str, changelog: str) -> bool:
         """Create a new release
 
@@ -97,15 +114,22 @@ class Github(Base):
         :return: Whether the request succeeded
         """
         response = requests.post(
-            f'{Github.API_URL}/repos/{owner}/{repo}/releases',
-            json={'tag_name': tag, 'body': changelog, 'draft': False, 'prerelease': False},
-            headers={'Authorization': 'token {}'.format(Github.token())}
+            f"{Github.API_URL}/repos/{owner}/{repo}/releases",
+            json={
+                "tag_name": tag,
+                "name": tag,
+                "body": changelog,
+                "draft": False,
+                "prerelease": False,
+            },
+            headers={"Authorization": "token {}".format(Github.token())},
         )
-        debug_gh('Release creation: status={}'.format(response.status_code))
+        logger.debug(f"Release creation status code: {response.status_code}")
 
         return response.status_code == 201
 
     @classmethod
+    @LoggedFunction(logger)
     def get_release(cls, owner: str, repo: str, tag: str) -> int:
         """Get a release by its tag name
 
@@ -118,15 +142,15 @@ class Github(Base):
         :return: ID of found release
         """
         response = requests.get(
-            f'{Github.API_URL}/repos/{owner}/{repo}/releases/tags/{tag}',
-            headers={'Authorization': 'token {}'.format(Github.token())}
+            f"{Github.API_URL}/repos/{owner}/{repo}/releases/tags/{tag}",
+            headers={"Authorization": "token {}".format(Github.token())},
         )
-        debug_gh('Get release by tag: status={}, release_id={}'.format(
-                 response.status_code, response.json()['id']))
+        logger.debug(f"Get release by tag status code: {response.status_code}")
 
-        return response.json()['id']
+        return response.json()["id"]
 
     @classmethod
+    @LoggedFunction(logger)
     def edit_release(cls, owner: str, repo: str, id: int, changelog: str) -> bool:
         """Edit a release with updated change notes
 
@@ -140,18 +164,19 @@ class Github(Base):
         :return: Whether the request succeeded
         """
         response = requests.post(
-            f'{Github.API_URL}/repos/{owner}/{repo}/releases/{id}',
-            json={'body': changelog},
-            headers={'Authorization': 'token {}'.format(Github.token())}
+            f"{Github.API_URL}/repos/{owner}/{repo}/releases/{id}",
+            json={"body": changelog},
+            headers={"Authorization": "token {}".format(Github.token())},
         )
-        debug_gh('Edit release: status={}, release_id={}'.format(
-                 response.status_code, id))
+        logger.debug(f"Edit release status code: {response.status_code}")
 
         return response.status_code == 200
 
     @classmethod
+    @LoggedFunction(logger)
     def post_release_changelog(
-            cls, owner: str, repo: str, version: str, changelog: str) -> bool:
+        cls, owner: str, repo: str, version: str, changelog: str
+    ) -> bool:
         """Post release changelog
 
         :param owner: The owner namespace of the repository
@@ -161,21 +186,23 @@ class Github(Base):
 
         :return: The status of the request
         """
-        tag = f'v{version}'
-        debug_gh(f'Attempting to create release for {tag}')
+        tag = f"v{version}"
+        logger.debug(f"Attempting to create release for {tag}")
         success = Github.create_release(owner, repo, tag, changelog)
 
         if not success:
-            debug_gh('Unsuccessful, looking for an existing release to update')
+            logger.debug("Unsuccessful, looking for an existing release to update")
             release_id = Github.get_release(owner, repo, tag)
-            debug_gh(f'Updating release {release_id}')
+            logger.debug(f"Updating release {release_id}")
             success = Github.edit_release(owner, repo, release_id, changelog)
 
         return success
 
     @classmethod
+    @LoggedFunction(logger)
     def upload_asset(
-            cls, owner: str, repo: str, release_id: int, file: str, label: str = None) -> bool:
+        cls, owner: str, repo: str, release_id: int, file: str, label: str = None
+    ) -> bool:
         """Upload an asset to an existing release
 
         https://developer.github.com/v3/repos/releases/#upload-a-release-asset
@@ -188,24 +215,23 @@ class Github(Base):
 
         :return: The status of the request
         """
-        url = 'https://uploads.github.com/repos/{owner}/{repo}/releases/{id}/assets'
+        url = "https://uploads.github.com/repos/{owner}/{repo}/releases/{id}/assets"
 
         response = requests.post(
-            url.format(
-                owner=owner,
-                repo=repo,
-                id=release_id
-            ),
-            params={'name': os.path.basename(file), 'label': label},
+            url.format(owner=owner, repo=repo, id=release_id),
+            params={"name": os.path.basename(file), "label": label},
             headers={
-                'Authorization': 'token {}'.format(Github.token()),
-                'Content-Type': mimetypes.guess_type(file, strict=False)[0]
+                "Authorization": "token {}".format(Github.token()),
+                "Content-Type": mimetypes.guess_type(file, strict=False)[0],
             },
-            data=open(file, 'rb').read()
+            data=open(file, "rb").read(),
         )
-        debug_gh('Asset upload: url={}, status={}'.format(
-                 response.url, response.status_code))
-        debug_gh(response.json())
+        logger.debug(
+            "Asset upload completed, url: {}, status code: {}".format(
+                response.url, response.status_code
+            )
+        )
+        logger.debug(response.json())
         return response.status_code == 201
 
     @classmethod
@@ -215,15 +241,15 @@ class Github(Base):
         :param owner: The owner namespace of the repository
         :param repo: The repository name
         :param version: Version to upload for
-        :param path: Path to the dist  directory
+        :param path: Path to the dist directory
 
         :return: The status of the request
         """
 
         # Find the release corresponding to this version
-        release_id = Github.get_release(owner, repo, f'v{version}')
+        release_id = Github.get_release(owner, repo, f"v{version}")
         if not release_id:
-            debug_gh('No release found to upload assets to')
+            logger.debug("No release found to upload assets to")
             return False
 
         # Upload assets
@@ -240,7 +266,8 @@ class Github(Base):
 class Gitlab(Base):
     """Gitlab helper class
     """
-    API_URL = 'https://' + os.environ.get('CI_SERVER_HOST', 'gitlab.com')
+
+    API_URL = "https://" + os.environ.get("CI_SERVER_HOST", "gitlab.com")
 
     @staticmethod
     def domain() -> str:
@@ -248,7 +275,7 @@ class Gitlab(Base):
 
         :return: The Gitlab instance domain
         """
-        return os.environ.get('CI_SERVER_HOST', 'gitlab.com')
+        return os.environ.get("CI_SERVER_HOST", "gitlab.com")
 
     @staticmethod
     def token() -> Optional[str]:
@@ -256,9 +283,10 @@ class Gitlab(Base):
 
         :return: The Gitlab token environment variable (GL_TOKEN) value
         """
-        return os.environ.get('GL_TOKEN')
+        return os.environ.get("GL_TOKEN")
 
     @staticmethod
+    @LoggedFunction(logger)
     def check_build_status(owner: str, repo: str, ref: str) -> bool:
         """Check last build status
 
@@ -270,24 +298,28 @@ class Gitlab(Base):
         """
         gl = gitlab.Gitlab(Gitlab.API_URL, private_token=Gitlab.token())
         gl.auth()
-        jobs = (gl.projects.get(owner+'/'+repo)
-                  .commits.get(ref)
-                  .statuses.list())
+        jobs = gl.projects.get(owner + "/" + repo).commits.get(ref).statuses.list()
         for job in jobs:
-            if job['status'] not in ['success', 'skipped']:
-                if job['status'] == 'pending':
-                    debug_gl('check_build_status: job {} is still in pending status'
-                             .format(job['name']))
+            if job["status"] not in ["success", "skipped"]:
+                if job["status"] == "pending":
+                    logger.debug(
+                        "check_build_status: job {} is still in pending status".format(
+                            job["name"]
+                        )
+                    )
                     return False
-                elif job['status'] == 'failed' and not job['allow_failure']:
-                    debug_gl('check_build_status: job {} failed'
-                             .format(job['name']))
+                elif job["status"] == "failed" and not job["allow_failure"]:
+                    logger.debug(
+                        "check_build_status: job {} failed".format(job["name"])
+                    )
                     return False
         return True
 
     @classmethod
+    @LoggedFunction(logger)
     def post_release_changelog(
-            cls, owner: str, repo: str, version: str, changelog: str) -> bool:
+        cls, owner: str, repo: str, version: str, changelog: str
+    ) -> bool:
         """Post release changelog
 
         :param owner: The owner namespace of the repository
@@ -297,19 +329,21 @@ class Gitlab(Base):
 
         :return: The status of the request
         """
-        ref = 'v' + version
+        ref = "v" + version
         gl = gitlab.Gitlab(Gitlab.API_URL, private_token=Gitlab.token())
         gl.auth()
         try:
-            tag = gl.projects.get(owner+'/'+repo).tags.get(ref)
+            tag = gl.projects.get(owner + "/" + repo).tags.get(ref)
             tag.set_release_description(changelog)
         except gitlab.exceptions.GitlabGetError:
-            debug_gl('Tag {} was not found for project {}'
-                     .format(ref, owner+'/'+repo))
+            logger.debug(
+                "Tag {} was not found for project {}".format(ref, owner + "/" + repo)
+            )
             return False
         except gitlab.exceptions.GitlabUpdateError:
-            debug_gl('Failed to update tag {} for project {}'
-                     .format(ref, owner+'/'+repo))
+            logger.debug(
+                "Failed to update tag {} for project {}".format(ref, owner + "/" + repo)
+            )
             return False
 
         return True
@@ -320,8 +354,8 @@ def get_hvcs() -> Base:
 
     :raises ImproperConfigurationError: if the hvcs option provided is not valid
     """
-    hvcs = config.get('semantic_release', 'hvcs')
-    debug('get_hvcs: hvcs=', hvcs)
+    hvcs = config.get("semantic_release", "hvcs")
+    logger.debug("get_hvcs: hvcs=", hvcs)
     try:
         return globals()[hvcs.capitalize()]
     except KeyError:
@@ -337,7 +371,7 @@ def check_build_status(owner: str, repository: str, ref: str) -> bool:
     :param ref: Commit or branch reference
     :return: A boolean with the build status
     """
-    debug('check_build_status')
+    logger.debug("check_build_status")
     return get_hvcs().check_build_status(owner, repository, ref)
 
 
@@ -351,7 +385,11 @@ def post_changelog(owner: str, repository: str, version: str, changelog: str) ->
     :param changelog: A string with the changelog in correct format
     :return: a tuple with success status and payload from hvcs
     """
-    debug('post_changelog(owner={}, repository={}, version={})'.format(owner, repository, version))
+    logger.debug(
+        "post_changelog(owner={}, repository={}, version={})".format(
+            owner, repository, version
+        )
+    )
     return get_hvcs().post_release_changelog(owner, repository, version, changelog)
 
 
